==> estateplat-common-1.2.4-20201113.091216-505-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlCfdjBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlCfdj;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlCfdjBdc extends QlfQlCfdj {
    private String dfcflxdm;
    private String dfcflxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    @XmlAttribute(
            name = "DFCFLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfcflxdm() {
        return dfcflxdm;
    }

    public void setDfcflxdm(String dfcflxdm) {
        this.dfcflxdm = dfcflxdm;
    }
    @XmlAttribute(
            name = "DFCFLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfcflxmc() {
        return dfcflxmc;
    }

    public void setDfcflxmc(String dfcflxmc) {
        this.dfcflxmc = dfcflxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
}

==> estateplat-common-1.2.4-20201116.061044-508-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlCfdjBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlCfdj;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlCfdjBdc extends QlfQlCfdj {
    private String dfcflxdm;
    private String dfcflxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    @XmlAttribute(
            name = "DFCFLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfcflxdm() {
        return dfcflxdm;
    }

    public void setDfcflxdm(String dfcflxdm) {
        this.dfcflxdm = dfcflxdm;
    }
    @XmlAttribute(
            name = "DFCFLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfcflxmc() {
        return dfcflxmc;
    }

    public void setDfcflxmc(String dfcflxmc) {
        this.dfcflxmc = dfcflxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
}
